==> jugg-agile-spring-boot-webmvc-1.0.0-20251126.015012-1-sources.jar: com/jugg/agile/spring/boot/webmvc/servlet/JaServletFilter.java <==
package com.jugg.agile.spring.boot.webmvc.servlet;

import com.jugg.agile.framework.core.dapper.alarm.JaAlarmWebhook;
import com.jugg.agile.framework.core.dapper.log.JaDapperLog;
import com.jugg.agile.framework.core.dapper.log.JaLog;
import com.jugg.agile.framework.core.dapper.log.JaMDC;
import com.jugg.agile.framework.core.util.JaThrowableUtil;
import com.jugg.agile.framework.meta.dto.JaResultDTO;
import com.jugg.agile.framework.meta.exception.JaException;
import com.jugg.agile.spring.boot.webmvc.context.JaWebContextChain;
import com.jugg.agile.spring.boot.webmvc.dapper.JaDapperWebProcessor;
import com.jugg.agile.spring.boot.webmvc.util.JaServletUtil;
import lombok.SneakyThrows;
import org.springframework.http.HttpStatus;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * controller 前置处理, 以防三方包内置controller未拦截到
 *
 * @author chenjian
 * @since 2024年01月05日 19:35:06
 */
public class JaServletFilter implements Filter {

    @Override
    public void init(FilterConfig filterConfig) {
        JaWebContextChain instance = JaWebContextChain.getInstance();
        JaLog.info("JaServletFilter init:{}", instance);
    }

    @Override
    @SneakyThrows
    public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain chain) {
        int connNums = JaDapperWebProcessor.Concurrency.incrementAndGet();
        HttpServletRequest request = (HttpServletRequest) servletRequest;
        HttpServletResponse response = (HttpServletResponse) servletResponse;
        String requestURI = request.getRequestURI();
        try {
            JaWebContextChain.getInstance().inherit(request);
            JaDapperWebProcessor.dapper(request, response);

            if (JaServletConfig.isPass(requestURI)) {
                chain.doFilter(servletRequest, servletResponse);
                return;
            }
            JaDapperLog.logEntry(requestURI, connNums);
//            JaDapperWebProcessor.checkUpServer(request);

            chain.doFilter(servletRequest, servletResponse);
        } catch (Throwable e) {
            handleException(request, response, e);
        } finally {
//            alarm(connNums);
            JaWebContextChain.getInstance().remove();
            JaDapperWebProcessor.Concurrency.decrementAndGet();
        }
    }

    @Override
    public void destroy() {
        JaAlarmWebhook.ScheduledThreadPoolExecutor.shutdownNow();
        JaLog.info("JaServletFilter destroy");
    }

    protected static void handleException(HttpServletRequest request, HttpServletResponse response, Throwable e) {
        JaLog.get().error("http filter catch ex", e);
        e = JaThrowableUtil.getCause(e);
        String code = null;
        String codeMsg = null;
        // TODO 未做国际化
        if (e instanceof JaException) {
            code = ((JaException) e).getCode();
        }
//        if (JaStringUtil.isEmpty(code)) {
//            codeMsg = JaI18nUtil.getMessage("Unknown Error"
//                    , request.getRequestURI()
//                    , JaMDC.get());
//        }
        codeMsg = String.format("Unknown Error:[%s]-[%s]"
                , request.getRequestURI()
                , JaMDC.get());
        JaResultDTO<Object> result = new JaResultDTO<>();
        result.setCode(code);
        result.setCodeMsg(codeMsg);
        response.setStatus(HttpStatus.HTTP_VERSION_NOT_SUPPORTED.value());
        JaServletUtil.printResponse(request, response, result);
    }

}

==> jugg-agile-spring-boot-webmvc-1.0.0-20251126.033218-3-sources.jar: com/jugg/agile/spring/boot/webmvc/servlet/JaServletFilter.java <==
package com.jugg.agile.spring.boot.webmvc.servlet;

import com.jugg.agile.framework.core.dapper.alarm.JaAlarmWebhook;
import com.jugg.agile.framework.core.dapper.log.JaDapperLog;
import com.jugg.agile.framework.core.dapper.log.JaLog;
import com.jugg.agile.framework.core.dapper.log.JaMDC;
import com.jugg.agile.framework.core.util.JaThrowableUtil;
import com.jugg.agile.framework.meta.dto.JaResultDTO;
import com.jugg.agile.framework.meta.exception.JaException;
import com.jugg.agile.spring.boot.webmvc.context.JaWebContextChain;
import com.jugg.agile.spring.boot.webmvc.dapper.JaDapperWebProcessor;
import com.jugg.agile.spring.boot.webmvc.util.JaServletUtil;
import lombok.SneakyThrows;
import org.springframework.http.HttpStatus;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * controller 前置处理, 以防三方包内置controller未拦截到
 *
 * @author chenjian
 * @since 2024年01月05日 19:35:06
 */
public class JaServletFilter implements Filter {
    public static int ErrorHttpStatus = HttpStatus.INTERNAL_SERVER_ERROR.value();

    @Override
    public void init(FilterConfig filterConfig) {
        JaWebContextChain instance = JaWebContextChain.getInstance();
        JaLog.info("JaServletFilter init:{}", instance);
    }

    @Override
    @SneakyThrows
    public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain chain) {
        int connNums = JaDapperWebProcessor.Concurrency.incrementAndGet();
        HttpServletRequest request = (HttpServletRequest) servletRequest;
        HttpServletResponse response = (HttpServletResponse) servletResponse;
        String requestURI = request.getRequestURI();
        try {
            JaWebContextChain.getInstance().inherit(request);
            JaDapperWebProcessor.dapper(request, response);

            if (JaServletConfig.isPass(requestURI)) {
                chain.doFilter(servletRequest, servletResponse);
                return;
            }
            JaDapperLog.logEntry(requestURI, connNums);
//            JaDapperWebProcessor.checkUpServer(request);

            chain.doFilter(servletRequest, servletResponse);
        } catch (Throwable e) {
            handleException(request, response, e);
        } finally {
//            alarm(connNums);
            JaWebContextChain.getInstance().remove();
            JaDapperWebProcessor.Concurrency.decrementAndGet();
        }
    }

    @Override
    public void destroy() {
        JaAlarmWebhook.ScheduledThreadPoolExecutor.shutdownNow();
        JaLog.info("JaServletFilter destroy");
    }

    protected static void handleException(HttpServletRequest request, HttpServletResponse response, Throwable e) {
        JaLog.get().error("http filter catch ex", e);
        e = JaThrowableUtil.getCause(e);
        String code = null;
        String codeMsg = null;
        // TODO 未做国际化
        if (e instanceof JaException) {
            code = ((JaException) e).getCode();
        }
//        if (JaStringUtil.isEmpty(code)) {
//            codeMsg = JaI18nUtil.getMessage("Unknown Error"
//                    , request.getRequestURI()
//                    , JaMDC.get());
//        }
        codeMsg = String.format("Unknown Error:[%s]-[%s]"
                , request.getRequestURI()
                , JaMDC.get());
        JaResultDTO<Object> result = new JaResultDTO<>();
        result.setCode(code);
        result.setCodeMsg(codeMsg);
        response.setStatus(ErrorHttpStatus);
        JaServletUtil.printResponse(request, response, result);
    }

}
